@@ -13,13 +13,13 @@ with inpkg():
     from .utils import encode_inst_id
 
 import os
+import cv2
 import OpenEXR
 import scipy.io
-from skimage.io import imsave
 
 
 class ExrDict(dict):
-    LIMIT_DEPTH = 1e8
+    LIMIT_DEPTH = 6e4
 
     def __getattribute__(self, key):
         if key in self:
@@ -35,10 +35,8 @@ class ExrDict(dict):
         return np.concatenate([self.get_rgb(), self["A"][..., None]], -1)
 
     def get_pseudo_color(self):
-
         limit_mask = self["Z"] < self.LIMIT_DEPTH
         depth = self["Z"] * limit_mask
-        # depth = np.log(depth + 1)
         depth = depth / depth.max()
         depth[~limit_mask] = 1.1
         depth = 1 - depth
@@ -87,7 +85,7 @@ class ImageWithAnnotation(dict):
             inst_dir = pathjoin(dataset_dir, "instance_map")
             os.makedirs(inst_dir, exist_ok=True)
             inst_path = pathjoin(inst_dir, fname + ".png")
-            imsave(inst_path, self["inst"].clip(0).astype(np.uint16))
+            cv2.imwrite(inst_path, self["inst"].clip(0).astype(np.uint16))
         if self.get("depth") is not None:
             depth_dir = pathjoin(dataset_dir, "depth")
             os.makedirs(depth_dir, exist_ok=True)
@@ -101,7 +99,7 @@ class ImageWithAnnotation(dict):
             vis_dir = pathjoin(dataset_dir, "vis")
             os.makedirs(vis_dir, exist_ok=True)
             vis_path = pathjoin(vis_dir, fname + ".jpg")
-            imsave(vis_path, self.vis())
+            cv2.imwrite(vis_path, self.vis()[..., ::-1])
         if self.get("ycb_6d_pose") is not None:
             pose_dir = pathjoin(dataset_dir, "ycb_6d_pose")
             os.makedirs(pose_dir, exist_ok=True)
@@ -112,7 +110,7 @@ class ImageWithAnnotation(dict):
             image_dir = pathjoin(dataset_dir, "image")
             os.makedirs(image_dir, exist_ok=True)
             image_path = pathjoin(image_dir, fname + ".jpg")
-            imsave(image_path, self["image"])
+            cv2.imwrite(image_path, self["image"][..., ::-1])
 
 
 def parser_exr(exr_path):
